@@ -7,6 +7,7 @@ import re
 import sys
 import cv2
 import os
+from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
 
 import numpy as np
 
@@ -22,15 +23,10 @@ class Client:
         to a data lake
     '''
 
-    client_uuid                         = ''
-    text_file_list                      = [".txt", ".tsv", ".csv"]
+    client_uuid = ''
+    text_file_list = [".txt", ".tsv", ".csv"]
 
-    __google_storage_client             = None
-    __patients_table_client             = None
-    __changelog_client                  = None
-    __data_standardizer                 = None
-
-    def __init__(self, google_clients, client_uuid):
+    def __init__(self, client_uuid):
         '''
             Init function that sets up client credentials, uuid, 
             and google api clients used to upload files to a GCS bucket
@@ -40,26 +36,9 @@ class Client:
             Returns:
                 None
         '''
-        self.client_uuid                = client_uuid
-        self.__google_storage_client    = google_clients.cloud_storage_client
-        logging_client                   = google_clients.cloud_logging_client
-        self.__file_upload_logger       = logging_client.logger(client_uuid + '-file-logger')
-        self.__patients_table_client    = Insert.Client(
-            google_clients, self.client_uuid)
-        self.__changelog_client         = ChnglogInsert.Client(
-            google_clients, self.client_uuid)
-        self.__data_standardizer        = PatientTable.Client()
-                
-
-    def close(self):
-        '''
-            Frees and destroys all allocated resources
-            Returns:
-                None
-        '''
-        self.__google_storage_client.close()
-        self.__patients_table_client.close()
-
+        self.client_uuid = client_uuid
+        self.__file_upload_logger = GcpClients.instance().get_logging_client(
+        ).logger(client_uuid + '-file-logger')
 
     def upload_file_to_datalake(self, modality, mrn, metadata, file_path):
         '''
@@ -77,32 +56,38 @@ class Client:
                     otherwise
                 
         '''
-        file_contents       = self.__read_file_contents(file_path)
-        file_extension      = os.path.splitext(file_path)[1]
+        file_contents = self.__read_file_contents(file_path)
+        file_extension = os.path.splitext(file_path)[1]
 
         # convert bmp to png
         if '.bmp' == file_extension.lower():
-            file_contents   = self.__convert_bmp_to_png(file_contents)
-            file_root       = os.path.splitext(file_path)[0]
-            file_path       = file_root + '.png'
-        
-        stripped_mrn        = self.__strip_leading_zeros(mrn)
-        hashed_patient_mrn  = Helpers.patient_hash(self.client_uuid, [stripped_mrn])[0]
-        hashed_file_name    = Helpers.hash_contents_to_file_name(file_path, file_contents)
-        blob_name           = modality + "/" + hashed_patient_mrn + "/" + hashed_file_name
-        bucket              = self.__google_storage_client.bucket(self.client_uuid)
-        blob                = bucket.blob(blob_name)
+            file_contents = self.__convert_bmp_to_png(file_contents)
+            file_root = os.path.splitext(file_path)[0]
+            file_path = file_root + '.png'
+
+        stripped_mrn = self.__strip_leading_zeros(mrn)
+        hashed_patient_mrn = Helpers.patient_hash(self.client_uuid,
+                                                  [stripped_mrn])[0]
+        hashed_file_name = Helpers.hash_contents_to_file_name(
+            file_path, file_contents)
+        blob_name = modality + "/" + hashed_patient_mrn + "/" + hashed_file_name
+        bucket = GcpClients.instance().get_storage_client().bucket(
+            self.client_uuid)
+        blob = bucket.blob(blob_name)
 
         if '.pdf' == file_extension.lower():
             blob.content_type = "application/pdf"
 
         if Helpers.try_blob_exists(blob):
             Helpers.print_error("File" + blob.name + " already exists")
-            self.__file_upload_logger.log_text("File" + blob.name + " already exists", severity='INFO')
+            self.__file_upload_logger.log_text("File" + blob.name +
+                                               " already exists",
+                                               severity='INFO')
             return True
 
         if not self.__create_blob_with_metadata(blob, file_contents, metadata):
-            Helpers.print_error("Could not upload file " + file_path + " to datalake")
+            Helpers.print_error("Could not upload file " + file_path +
+                                " to datalake")
             return False
 
         if hashed_patient_mrn != 'UNKNOWN'and \
@@ -111,8 +96,8 @@ class Client:
             return False
 
         blob.metadata = metadata
-        return self.__changelog_client.insert_to_changelog_table(blob, 'CREATED')
-
+        return ChnglogInsert.Client(self.client_uuid).insert_to_changelog_table(
+            blob, 'CREATED')
 
     def __convert_bmp_to_png(self, file_bytes):
         '''
@@ -122,15 +107,14 @@ class Client:
             Returns:
                 string: The converted bytes in string format
         '''
-        nparr       = np.frombuffer(file_bytes, dtype=np.uint8)
-        img         = cv2.imdecode(nparr, cv2.IMREAD_COLOR)
-        png_img     = cv2.imencode('.png', img)[1]
+        nparr = np.frombuffer(file_bytes, dtype=np.uint8)
+        img = cv2.imdecode(nparr, cv2.IMREAD_COLOR)
+        png_img = cv2.imencode('.png', img)[1]
         data_encode = np.array(png_img)
         byte_encode = data_encode.tobytes()
 
         return byte_encode
 
-
     def __strip_leading_zeros(self, string_to_strip):
         '''
             strips the leading '0' from a string
@@ -143,7 +127,6 @@ class Client:
 
         return stripped_string
 
-    
     def __insert_data_to_patients_table(self, mrn, hashed_patient_mrn):
         '''
             Inserts the file's patient to the patient table
@@ -151,20 +134,22 @@ class Client:
                 mrn (string): the patients mrn
                 hashed_patient_mrn (stirng): the patient id
         '''
-        patient_data = {"MRN":mrn, 
-                        "CLIENT_ID":self.client_uuid,
-                        "PATIENT_ID":hashed_patient_mrn
-                        }
+        patient_data = {
+            "MRN": mrn,
+            "CLIENT_ID": self.client_uuid,
+            "PATIENT_ID": hashed_patient_mrn
+        }
 
-        patient_data = self.__data_standardizer.standardize(patient_data)
-            
-        if self.__patients_table_client.insert_data_to_patients_table(patient_data):
+        patient_data = PatientTable.Client().standardize(patient_data)
+
+        if Insert.Client(
+                self.client_uuid).insert_data_to_patients_table(patient_data):
             return True
 
-        Helpers.print_error('Failed to upload ' + str(patient_data) + ' to patients table')
+        Helpers.print_error('Failed to upload ' + str(patient_data) +
+                            ' to patients table')
         return False
 
-
     def __create_blob_with_metadata(self, blob, file_contents, metadata):
         '''
             Creates the blob in GCS and adds metadata to it
@@ -177,23 +162,27 @@ class Client:
         '''
         # add metadata to blob and save in bucket
         blob.metadata = metadata
-        
+
         if not self.__try_upload_blob(blob, file_contents):
             return False
 
         if Helpers.try_blob_exists(blob):
             print('successfully uploaded file to datalake')
-            self.__file_upload_logger.log_text('successfully uploaded file ' + blob.name + ' to datalake', severity='INFO')
+            self.__file_upload_logger.log_text('successfully uploaded file ' +
+                                               blob.name + ' to datalake',
+                                               severity='INFO')
             if metadata['MODALITY'] != metadata['CLASSIFIED_MODALITY']:
-                self.__file_upload_logger.log_text('Classified Modality for ' 
-                    + blob.name + ' (' + metadata['CLASSIFIED_MODALITY'] + 
-                    ') does not matched metadata supplied (' + metadata['MODALITY'] + ')', severity='WARNING')
+                self.__file_upload_logger.log_text(
+                    'Classified Modality for ' + blob.name + ' (' +
+                    metadata['CLASSIFIED_MODALITY'] +
+                    ') does not matched metadata supplied (' +
+                    metadata['MODALITY'] + ')',
+                    severity='WARNING')
 
             return True
 
         return False
 
-
     def __read_file_contents(self, file_path):
         """
             Reads file from the file path, has the capabilities to read from local file,
@@ -205,8 +194,8 @@ class Client:
             Returns:
                 string: string representation of data found
         """
-        
-        extension       = os.path.splitext(file_path)[1].lower()
+
+        extension = os.path.splitext(file_path)[1].lower()
 
         if "gs://" in file_path:
             # GCS BUCKET
@@ -216,7 +205,7 @@ class Client:
             else:
                 file_bytes = self.__read_gcs_blob(file_path)
                 return file_bytes
-        
+
         # LOCAL FILE
         if extension in self.text_file_list:
             content = open(file_path, 'rb').read()
@@ -224,7 +213,6 @@ class Client:
         else:
             file_bytes = open(file_path, 'rb').read()
             return file_bytes
-    
 
     def __read_gcs_blob(self, gcs_blob_path):
         '''
@@ -234,12 +222,11 @@ class Client:
             Returns:
                 bytes: contents of the gcs blob
         '''
-        file_path           = gcs_blob_path.replace("gs://", "")
-        bucket_name         = file_path.split("/")[0]
-        source_blob_name    = file_path.split("/", 1)[1]
-        extension           = file_path.split("/")[-1].split(".")[-1].lower()
-        bucket              = self.__google_storage_client.bucket(bucket_name)
-        blob                = bucket.blob(source_blob_name)
+        file_path = gcs_blob_path.replace("gs://", "")
+        bucket_name = file_path.split("/")[0]
+        source_blob_name = file_path.split("/", 1)[1]
+        bucket = GcpClients.instance().get_storage_client().bucket(bucket_name)
+        blob = bucket.blob(source_blob_name)
 
         content = blob.download_as_bytes()
 
@@ -258,6 +245,8 @@ class Client:
             return True
         except Exception as e:
             Helpers.print_error("Could not upload blob " + str(e))
-            self.__file_upload_logger.log_text('Failed To Upload Blob ' 
-                + blob.name + ' using GCS client: ' + str(e), severity='ERROR')
-            return False
\ No newline at end of file
+            self.__file_upload_logger.log_text(
+                'Failed To Upload Blob ' + blob.name + ' using GCS client: ' +
+                str(e),
+                severity='ERROR')
+            return False
