@@ -12,6 +12,8 @@ from indxdatalaketools.ClientTools.PatientsTable import table_schema_pb2
 from indxdatalaketools.ClientTools.PatientsTable import Update
 from indxdatalaketools import Helpers
 from indxdatalaketools.GoogleClientWrappers import BigQuery
+from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
+
 
 class Client:
     '''
@@ -19,19 +21,21 @@ class Client:
         The patient table
     '''
 
-    client_uuid                         = ''
-    dataset_id                          = ''
-    patient_table_name                  = ''
-    table_fields                        = ["CLIENT_ID","MRN","PATIENT_ID","FIRSTNAME",
-            "MIDDLENAME","LASTNAME","DOB","SEX","RACE", 'CHECKSUM','UPDATED_AT']
-    __patient_insert_logger             = None
-    __proto_buf_dictionary              = None
-    __google_big_query_client           = None
-    __google_big_query_storage_client   = None
-    __big_query_wrapper                 = None
-    __patient_table_update_client       = None
+    client_uuid = ''
+    dataset_id = ''
+    patient_table_name = ''
+    table_fields = [
+        "CLIENT_ID", "MRN", "PATIENT_ID", "FIRSTNAME", "MIDDLENAME", "LASTNAME",
+        "DOB", "SEX", "RACE", 'CHECKSUM', 'UPDATED_AT'
+    ]
+    __patient_insert_logger = None
+    __proto_buf_dictionary = None
+    __google_big_query_client = None
+    __google_big_query_storage_client = None
+    __big_query_wrapper = None
+    __patient_table_update_client = None
 
-    def __init__(self, google_clients, client_uuid):
+    def __init__(self, client_uuid):
         '''
             Init function that sets up client credentials, uuid, 
             and google api clients used to insert items to the Patients table
@@ -41,16 +45,14 @@ class Client:
             Returns:
                 None
         '''
-        self.client_uuid                        = client_uuid
-        self.dataset_id                         = self.client_uuid.replace("-", "_")
+        self.client_uuid = client_uuid
+        self.dataset_id = self.client_uuid.replace("-", "_")
         self.patient_table_name                 = 'indx-data-services.' + \
             self.dataset_id + ".PATIENTS"
-        self.__google_big_query_client          = google_clients.big_query_client
-        self.__google_big_query_storage_client  = google_clients.big_query_storage_v1_client
-        logging_client                          = google_clients.cloud_logging_client
-        self.__patient_insert_logger            = logging_client.logger(client_uuid + '-patient-logger')
-        self.__patient_table_update_client      = Update.Client(google_clients, client_uuid)
-        self.__big_query_wrapper                = BigQuery.Wrapper(google_clients)
+
+        logging_client = GcpClients.instance().get_logging_client()
+        self.__patient_insert_logger = logging_client.logger(client_uuid +
+                                                             '-patient-logger')
         self.__create_proto_buf_dictionary()
 
     def __create_proto_buf_dictionary(self):
@@ -59,30 +61,19 @@ class Client:
             its attributes easily
         '''
         self.__proto_buf_dictionary = {
-            "CLIENT_ID":    self.__insert_client_id, 
-            "MRN":          self.__insert_mrn,
-            "PATIENT_ID":   self.__insert_patient_id,
-            "FIRSTNAME":    self.__insert_first_name,
-            "MIDDLENAME":   self.__insert_middle_name,
-            "LASTNAME":     self.__insert_last_name,
-            "DOB":          self.__insert_dob,
-            "SEX":          self.__insert_sex,
-            "RACE":         self.__insert_race,
-            "CHECKSUM":     self.__insert_checksum,
-            "UPDATED_AT":   self.__insert_updated_at,
+            "CLIENT_ID": self.__insert_client_id,
+            "MRN": self.__insert_mrn,
+            "PATIENT_ID": self.__insert_patient_id,
+            "FIRSTNAME": self.__insert_first_name,
+            "MIDDLENAME": self.__insert_middle_name,
+            "LASTNAME": self.__insert_last_name,
+            "DOB": self.__insert_dob,
+            "SEX": self.__insert_sex,
+            "RACE": self.__insert_race,
+            "CHECKSUM": self.__insert_checksum,
+            "UPDATED_AT": self.__insert_updated_at,
         }
 
-
-    def close(self):
-        '''
-            Frees and destroys all allocated resources
-            Returns:
-                None
-        '''
-        self.__google_big_query_client.close()
-        self.__patient_table_update_client.close()
-    
-
     def insert_data_to_patients_table(self, patient_json, overwrite=False):
         '''
             This function determines whether the patient_json is a list
@@ -97,15 +88,18 @@ class Client:
                 boolean: True if the patient/s were succesfully inserted in the PATIENTS table
         '''
         # parse json to determine single or multiple patients
-        
+
         # multiple patients
         if isinstance(patient_json, list):
-            return self.__insert_multiple_patients_to_table(patient_json)
-        
-        return self.__insert_patient_to_patients_table(patient_json, overwrite=overwrite)
-                
-    
-    def __insert_multiple_patients_to_table(self, json_structure, overwrite=False):
+            return self.__insert_multiple_patients_to_table(patient_json,
+                                                            overwrite=overwrite)
+
+        return self.__insert_patient_to_patients_table(patient_json,
+                                                       overwrite=overwrite)
+
+    def __insert_multiple_patients_to_table(self,
+                                            json_structure,
+                                            overwrite=False):
         '''
             loops through json structure and inserts all patients into the PATIENTS
             table, if a patient is not successfully uploaded then it is logged and
@@ -126,13 +120,13 @@ class Client:
 
         if status == False:
             self.__patient_insert_logger.log_text(
-                'One or more patients have not been uploaded Successfully', severity='ERROR')
+                'One or more patients have not been uploaded Successfully',
+                severity='ERROR')
 
         self.__patient_insert_logger.log_text(
             'All patients have been uploaded Successfully', severity='INFO')
         return status
 
-
     def __insert_patient_to_patients_table(self, patient_data, overwrite=False):
         '''
             Function that adds a single patient to the patient table, if that patient already exists
@@ -144,14 +138,16 @@ class Client:
             Returns:
                 boolean: True if the operation was a success, false if otherwise
         '''
-        now                         = datetime.datetime.utcnow()
-        patient_data['UPDATED_AT']  = str(now).replace(' ','T')
-        patient_mrn                 = patient_data['MRN']
-        patient_id                  = Helpers.patient_hash(self.client_uuid, [patient_mrn])[0]
-        patient_row                 = self.__get_patient_in_patients_table(patient_mrn, patient_id)
-        
-        return self.__insert_data_to_patients_table(patient_data, patient_row, overwrite)
+        now = datetime.datetime.utcnow()
+        patient_data['UPDATED_AT'] = str(now).replace(' ', 'T')
+        patient_mrn = patient_data['MRN']
+        patient_id = Helpers.patient_hash(self.client_uuid, [patient_mrn])[0]
+        patient_row = self.__get_patient_in_patients_table(
+            patient_mrn, patient_id)
 
+        return self.__insert_data_to_patients_table(patient_data,
+                                                    patient_row,
+                                                    overwrite=overwrite)
 
     def __get_patient_in_patients_table(self, patient_mrn, patient_id):
         '''
@@ -163,26 +159,29 @@ class Client:
             Returns:
                 The row of the Patient, if they are not in the table None is returned
         '''
-        query       = 'SELECT * \
-                    FROM `'+self.patient_table_name+'`\
-                    WHERE MRN =\'' + patient_mrn +'\'\
-                    AND PATIENT_ID =\'' +patient_id + '\''
-        rows        = self.__big_query_wrapper.perform_query(query)
+        query = 'SELECT * \
+                    FROM `' + self.patient_table_name + '`\
+                    WHERE MRN =\'' + patient_mrn + '\'\
+                    AND PATIENT_ID =\'' + patient_id + '\''
+        rows = BigQuery.Wrapper().perform_query(query)
         if rows is None:
             return None
 
         if rows.total_rows == 0:
             return None
         if rows.total_rows > 1:
-            Helpers.print_error("CRITICAL: Error in PATIENTS table, multiple instances of MRN: " + patient_mrn +
-            " and PATIENT_ID " + patient_id)
+            Helpers.print_error(
+                "CRITICAL: Error in PATIENTS table, multiple instances of MRN: "
+                + patient_mrn + " and PATIENT_ID " + patient_id)
 
         # must only contain one row if not 0 and > 1
         for row in rows:
-            return row    
+            return row
 
-
-    def __insert_data_to_patients_table(self, patient_data, patient_row, overwrite=False):
+    def __insert_data_to_patients_table(self,
+                                        patient_data,
+                                        patient_row,
+                                        overwrite=False):
         '''
             Inserts data to the patients table, if the data needs to be updated it will overwrite
             if the flag is set
@@ -196,16 +195,16 @@ class Client:
         '''
         if patient_row is not None:
             # patient exists, updated patient in table
-            return self.__patient_table_update_client.update_patient_in_patient_table(
-                patient_data, patient_row, overwrite=overwrite)
-        elif overwrite == False:               
+            return Update.Client(
+                self.client_uuid).update_patient_in_patient_table(
+                    patient_data, patient_row, overwrite=overwrite)
+        elif overwrite == False:
             # if not append to PATIENTS table
             return self.__add_data_to_patient_table(patient_data)
         else:
             Helpers.print_error("patient does not exist cannot update")
             return False
 
-
     def __add_data_to_patient_table(self, patient_data):
         '''
             Adds the patients data to the PATIENT table using the Big Query 
@@ -215,53 +214,59 @@ class Client:
             Returns
                 Boolean: True if the request worked, false if other wise
         '''
-        parent                          = self.__google_big_query_storage_client\
+        parent                          = GcpClients.instance().get_bigquery_storage_v1_client()\
             .table_path("indx-data-services", self.dataset_id, "PATIENTS")
-        write_stream                    = types.WriteStream()
-        write_stream.type_              = types.WriteStream.Type.COMMITTED
-        write_stream                    = self.__google_big_query_storage_client\
+        write_stream = types.WriteStream()
+        write_stream.type_ = types.WriteStream.Type.COMMITTED
+        write_stream                    = GcpClients.instance().get_bigquery_storage_v1_client()\
             .create_write_stream(
             parent=parent, write_stream=write_stream
         )
-        stream_name                     = write_stream.name
+        stream_name = write_stream.name
 
         # Create a template with fields needed for the first request.
-        request_template                = types.AppendRowsRequest()
+        request_template = types.AppendRowsRequest()
 
         # The initial request must contain the stream name.
-        request_template.write_stream   = stream_name
+        request_template.write_stream = stream_name
 
         # So that BigQuery knows how to parse the serialized_rows, generate a
         # protocol buffer representation of your message descriptor.
-        proto_schema                    = types.ProtoSchema()
-        proto_descriptor                = descriptor_pb2.DescriptorProto()
-        table_schema_pb2.table_schema_pb2.DESCRIPTOR.CopyToProto(proto_descriptor)
-        proto_schema.proto_descriptor   = proto_descriptor
-        proto_data                      = types.AppendRowsRequest.ProtoData()
-        proto_data.writer_schema        = proto_schema
-        request_template.proto_rows     = proto_data
+        proto_schema = types.ProtoSchema()
+        proto_descriptor = descriptor_pb2.DescriptorProto()
+        table_schema_pb2.table_schema_pb2.DESCRIPTOR.CopyToProto(
+            proto_descriptor)
+        proto_schema.proto_descriptor = proto_descriptor
+        proto_data = types.AppendRowsRequest.ProtoData()
+        proto_data.writer_schema = proto_schema
+        request_template.proto_rows = proto_data
 
         # Create a batch of row data by appending proto2 serialized bytes to the
         # serialized_rows repeated field.
-        
-        serialized_row  = self.__create_proto_buf_row(patient_data)
+
+        serialized_row = self.__create_proto_buf_row(patient_data)
         if serialized_row is None:
             return False
-        response_future_1 = self.__big_query_wrapper.insert_to_bq_table(
-            self.__google_big_query_storage_client, serialized_row, request_template, stream_name, parent)
-        
+        response_future_1 = BigQuery.Wrapper().insert_to_bq_table(
+            GcpClients.instance().get_bigquery_storage_v1_client(),
+            serialized_row, request_template, stream_name, parent)
+
         if response_future_1.done():
-            self.__patient_insert_logger.log_text('successfully inserted ' + 
-                str(patient_data) + ' to PATIENTS table', severity='INFO')
-            print('successfully inserted Patient ' + str(patient_data['MRN']) + ' to PATIENTS table')
+            self.__patient_insert_logger.log_text('successfully inserted ' +
+                                                  str(patient_data) +
+                                                  ' to PATIENTS table',
+                                                  severity='INFO')
+            print('successfully inserted Patient ' + str(patient_data['MRN']) +
+                  ' to PATIENTS table')
             return True
 
-        Helpers.print_error('Failed to insert Patient ' + str(patient_data['MRN']) + ' to PATIENTS table')
-        self.__patient_insert_logger.log_text('Failed to insert ' + 
-                str(patient_data) + ' to PATIENTS table', severity='ERROR')
+        Helpers.print_error('Failed to insert Patient ' +
+                            str(patient_data['MRN']) + ' to PATIENTS table')
+        self.__patient_insert_logger.log_text(
+            'Failed to insert ' + str(patient_data) + ' to PATIENTS table',
+            severity='ERROR')
         return False
-            
-    
+
     def __create_proto_buf_row(self, patient_data):
         '''
             Creates a protobuf table_schema object to insert into a
@@ -272,20 +277,20 @@ class Client:
                 serialized proto buf: The serialized proto buf object of the passed
                     dictionary
         '''
-        row             = table_schema_pb2.table_schema_pb2()
+        row = table_schema_pb2.table_schema_pb2()
         for field in self.table_fields:
 
             if field in patient_data:
-                row = self.__proto_buf_dictionary[field](row, patient_data[field])
+                row = self.__proto_buf_dictionary[field](row,
+                                                         patient_data[field])
 
         try:
             return row.SerializeToString()
         except Exception as e:
-            self.__patient_insert_logger.log_text("error creating protocol buffer " + str(e),
-            severity='ERROR')
+            self.__patient_insert_logger.log_text(
+                "error creating protocol buffer " + str(e), severity='ERROR')
             return None
-        
-        
+
     def __insert_client_id(self, row, client_id):
         if client_id is None:
             return row
@@ -326,15 +331,15 @@ class Client:
         if dob is None:
             return row
 
-        dob     = dob.split("-")
-        year    = int(dob[0])
-        month   = int(dob[1])
-        day     = int(dob[2])
-        date    = datetime.date(year, month, day)
+        dob = dob.split("-")
+        year = int(dob[0])
+        month = int(dob[1])
+        day = int(dob[2])
+        date = datetime.date(year, month, day)
         past_date = datetime.date(1970, 1, 1)
         row.DOB = int((date - past_date).days)
         return row
-    
+
     def __insert_sex(self, row, sex):
         if sex is None:
             return row
