@@ -3,32 +3,27 @@
 #   Created on 2/21/2022
 #
 
-
 import datetime
 from indxdatalaketools import Helpers
+from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
 from indxdatalaketools.Helpers import print_error
 from indxdatalaketools.GoogleClientWrappers import BigQuery
 from indxdatalaketools.PatientsHoldingApi import HoldingTable
 
 
-
 class Client:
     '''
         Class that handles all functionlaity to update a patient in the PATIENTS table
     '''
-    client_uuid                         = ''
-    dataset_id                          = ''
-    patient_table_name                  = ''
-    overwrite                           = False
+    client_uuid = ''
+    dataset_id = ''
+    patient_table_name = ''
+    overwrite = False
 
-    __patient_insert_logger             = None
-    __google_big_query_client           = None
-    __big_query_wrapper                 = None
-    __holding_table_api                 = None
-    
+    __patient_insert_logger = None
+    __big_query_wrapper = None
 
-
-    def __init__(self, google_clients, client_uuid):
+    def __init__(self, client_uuid):
         '''
             Init function that sets up client credentials, uuid, 
             and google big query client used to insert items to the Patients table
@@ -38,26 +33,18 @@ class Client:
             Returns:
                 None
         '''
-        self.client_uuid                        = client_uuid
-        self.dataset_id                         = "indx-data-services."+self.client_uuid.\
+        self.client_uuid = client_uuid
+        self.dataset_id = "indx-data-services."+self.client_uuid.\
             replace("-", "_")
-        self.patient_table_name                 = self.dataset_id + ".PATIENTS"
-        self.__google_big_query_client          = google_clients.big_query_client
-        logging_client                          = google_clients.cloud_logging_client
-        self.__patient_insert_logger            = logging_client.logger(client_uuid + '-patient-logger')
-        self.__big_query_wrapper                = BigQuery.Wrapper(google_clients)
-        self.__holding_table_api                = HoldingTable.Client(google_clients)
+        self.patient_table_name = self.dataset_id + ".PATIENTS"
+        logging_client = GcpClients.instance().get_logging_client()
+        self.__patient_insert_logger = logging_client.logger(client_uuid +
+                                                             '-patient-logger')
 
-    def close(self):
-        '''
-            Frees and destroys all allocated resources
-            Returns:
-                None
-        '''
-        self.__google_big_query_client.close()
-
-        
-    def update_patient_in_patient_table(self, patient_data, patient_row, overwrite=False):
+    def update_patient_in_patient_table(self,
+                                        patient_data,
+                                        patient_row,
+                                        overwrite=False):
         '''
             function that checks to see if the patient in the table needs to get updated or not
             and then applies the update if applicable.
@@ -74,22 +61,28 @@ class Client:
         if self.__compare_dict_to_table_row(patient_data, patient_row):
             # The Patient Data is updatable so update
             time_now = datetime.datetime.utcnow()
-            patient_update_time = datetime.datetime.fromisoformat(str(patient_row.get("UPDATED_AT")))
+            patient_update_time = datetime.datetime.fromisoformat(
+                str(patient_row.get("UPDATED_AT")))
             if time_now < patient_update_time + datetime.timedelta(minutes=90):
-                
+
                 patient_data['UPDATED_AT'] = None
                 patient_data = Helpers.convert_keys_in_dictionary(patient_data)
                 patient_data['action'] = "UPDATED"
-                return self.__holding_table_api.insert_data_to_holding_table(patient_data)
+                self.__patient_insert_logger.log_text(
+                    'staging patient data ' + str(patient_data) + " for update",
+                    severity='INFO')
+                return HoldingTable.Client().insert_data_to_holding_table(
+                    patient_data)
 
-            return self.__update_patients_table_row_with_dml(patient_data, 
-                patient_row=patient_row)
+            return self.__update_patients_table_row_with_dml(
+                patient_data, patient_row=patient_row)
 
         print("Nothing to Update for Patient " + patient_data["PATIENT_ID"])
         return True
 
-
-    def __update_patients_table_row_with_dml(self, patient_data, patient_row=None):
+    def __update_patients_table_row_with_dml(self,
+                                             patient_data,
+                                             patient_row=None):
         '''
             This function updates the row of a table with new data. CLIENT_ID, PATIENT_ID,
             and MRN cannot be updated. This function builds the DPL query based on what the client
@@ -102,15 +95,16 @@ class Client:
                 Boolean: True if the operation was succesfull, false if otherwise
         '''
         dml_query = self.__create_dml_update_query(patient_data, patient_row)
-        if self.__big_query_wrapper.perform_query(dml_query) is None:
-            self.__patient_insert_logger.log_text('could not update patient info ' 
-            + patient_data, severity='WARNING')
+        if BigQuery.Wrapper().perform_query(dml_query) is None:
+            self.__patient_insert_logger.log_text(
+                'could not update patient info ' + str(patient_data),
+                severity='WARNING')
             return False
 
-        self.__patient_insert_logger.log_text('updated patient info ' 
-            + patient_data, severity='INFO')
+        self.__patient_insert_logger.log_text('updated patient info ' +
+                                              str(patient_data),
+                                              severity='INFO')
         return True
-        
 
     def __create_dml_update_query(self, patient_data, patient_row=None):
         '''
@@ -123,19 +117,21 @@ class Client:
             Returns:
                 string: The query we wish to run on the PATIENTS table
         '''
-        table_name  = "indx-data-services."+self.client_uuid.replace('-','_')+".PATIENTS"
-        dml_query   = 'UPDATE `' + table_name + '` SET '
+        table_name = "indx-data-services." + self.client_uuid.replace(
+            '-', '_') + ".PATIENTS"
+        dml_query = 'UPDATE `' + table_name + '` SET '
 
         for k in patient_data:
-            dml_query += self.__populate_changed_keys_in_query(k, patient_row.get(k), patient_data[k])
+            dml_query += self.__populate_changed_keys_in_query(
+                k, patient_row.get(k), patient_data[k])
 
         # remove last comma
-        dml_query   = dml_query[:-2] + ' '
-        dml_query   += 'WHERE PATIENT_ID = \'' + patient_data['PATIENT_ID'] + '\''
+        dml_query = dml_query[:-2] + ' '
+        dml_query += 'WHERE PATIENT_ID = \'' + patient_data['PATIENT_ID'] + '\''
         return dml_query
 
-    
-    def __populate_changed_keys_in_query(self, key, patient_row_value, patient_data_value):
+    def __populate_changed_keys_in_query(self, key, patient_row_value,
+                                         patient_data_value):
         '''
             Populates all keys that are to be updated for the patient
             Args:
@@ -150,20 +146,25 @@ class Client:
                     to be added
         '''
         #Client ID, Patient ID, and MRN are immutable
-        if key == "CLIENT_ID" or key == "MRN" or key == "PATIENT_ID" \
-            or patient_data_value is None:
+        if key == "CLIENT_ID" or key == "MRN" or key == "PATIENT_ID":
+            return ''
+
+        if self.overwrite == False and patient_data_value is None:
             return ''
 
         # New information can always be added to a patient record
-        if self.overwrite == False and patient_row_value is None :
+        if self.overwrite == False and patient_row_value is None:
             return key + ' = \'' + str(patient_data_value) + '\', '
 
         # Overwriting existing information requires a special command
         if self.overwrite == True and patient_data_value is not None:
             return key + ' = \'' + str(patient_data_value) + '\', '
 
-        return ''
+        # overwriting existing
+        if self.overwrite == True and patient_data_value is None:
+            return key + ' = DEFAULT, '
 
+        return ''
 
     def __compare_dict_to_table_row(self, patient_data, patient_row):
         '''
@@ -180,8 +181,8 @@ class Client:
                 True if a patient needs to be updated, false if otherwise.
         '''
 
-        status=True
-        
+        status = True
+
         if self.overwrite == True:
             return True
 
@@ -191,16 +192,15 @@ class Client:
 
         # compare, the changes in the two records
         for k in patient_data:
-            if k == "CLIENT_ID" or k == "MRN" or k == "PATIENT_ID" or k == "UPDATED_AT":
+            if k == "CLIENT_ID" or k == "MRN" or k == "PATIENT_ID" \
+            or k == "UPDATED_AT" or k == "CHECKSUM":
                 continue
-            
+
             elif not self.__is_updateable(patient_data[k], patient_row.get(k)):
                 status = False
 
-
         return status
 
-    
     def __compare_checksum(self, patient_data, patient_row):
         '''
             Function that compares the tnew value and old values checksum to see if 
@@ -213,12 +213,11 @@ class Client:
             Returns:
                 boolean: True if the values are the same, False if they are different
         '''
-        if patient_data['CHECKSUM'] == patient_row.get('CHECKSUM'): 
+        if patient_data['CHECKSUM'] == patient_row.get('CHECKSUM'):
             return True
 
         return False
 
-
     def __is_updateable(self, input_value, existing_value):
         '''
             Function that checks whether or not there is new data in the
@@ -239,17 +238,18 @@ class Client:
 
         if input_value is not None and existing_value is None:
             # can update the patient
-            print(input_value, existing_value)
             return True
-            
+
         if input_value is not None and existing_value is not None and self.overwrite == False:
             if input_value == existing_value:
                 # no change here
                 return True
+            print(input_value, existing_value)
             # different values cannot overwrite, not updateable
-            print_error("Cannot overide values in the PATIENT table using this command," +
-            " try patients-table update command instead.")
+            print_error(
+                "Cannot overide values in the PATIENT table using this command,"
+                + " try patients-table update command instead.")
             return False
-        
+
         # default changeable
         return True
\ No newline at end of file
