@@ -11,13 +11,13 @@ from google.cloud import bigquery
 from google.api_core.exceptions import NotFound
 from indxdatalaketools import Helpers
 from indxdatalaketools.DataLakeGlobals import DATASET_OWNER
+from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
 from indxdatalaketools.Helpers import print_error
 from google.cloud.bigquery_storage_v1 import types
 from google.cloud.bigquery_storage_v1 import writer
 from google.cloud.bigquery.enums import EntityTypes
 
 
-
 class Wrapper:
     '''
         Wrapper for Google Cloud Platform Big Query python SDK
@@ -25,16 +25,16 @@ class Wrapper:
 
     __google_big_query_client = None
     file_format_map = {
-        'AVRO':bigquery.SourceFormat.AVRO,
-        'CSV':bigquery.SourceFormat.CSV
-        }
-    
-    
-    def __init__(self, google_clients):
-        self.__google_big_query_client = google_clients.big_query_client
+        'AVRO': bigquery.SourceFormat.AVRO,
+        'CSV': bigquery.SourceFormat.CSV
+    }
 
+    def __init__(self):
+        self.__google_big_query_client = GcpClients.instance(
+        ).get_bigquery_client()
 
-    def insert_to_bq_table(self, bq_storage_client, serialized_row, request_template, stream_name, parent):
+    def insert_to_bq_table(self, bq_storage_client, serialized_row,
+                           request_template, stream_name, parent):
         '''
             Function that inserts data into a big query table
             Args:
@@ -47,8 +47,9 @@ class Wrapper:
             Returns:
                 repsonse: The response from the API call
         '''
-        append_rows_stream = writer.AppendRowsStream(bq_storage_client, request_template)
-        proto_rows      = types.ProtoRows()
+        append_rows_stream = writer.AppendRowsStream(bq_storage_client,
+                                                     request_template)
+        proto_rows = types.ProtoRows()
         proto_rows.serialized_rows.append(serialized_row)
 
         # Set an offset to allow resuming this stream if the connection breaks.
@@ -58,12 +59,12 @@ class Wrapper:
         # error, which can be safely ignored.
         #
         # The first request must always have an offset of 0.
-        request                 = types.AppendRowsRequest()
-        request.offset          = 0
-        proto_data              = types.AppendRowsRequest.ProtoData()
-        proto_data.rows         = proto_rows
-        request.proto_rows      = proto_data
-        request.write_stream    = stream_name
+        request = types.AppendRowsRequest()
+        request.offset = 0
+        proto_data = types.AppendRowsRequest.ProtoData()
+        proto_data.rows = proto_rows
+        request.proto_rows = proto_data
+        request.write_stream = stream_name
 
         try:
             response_future_1 = append_rows_stream.send(request)
@@ -75,14 +76,15 @@ class Wrapper:
 
         bq_storage_client.finalize_write_stream(name=stream_name)
 
-        batch_commit_write_streams_request                  = types.BatchCommitWriteStreamsRequest()
-        batch_commit_write_streams_request.parent           = parent
-        batch_commit_write_streams_request.write_streams    = [stream_name]
-        bq_storage_client.batch_commit_write_streams(batch_commit_write_streams_request)
+        batch_commit_write_streams_request = types.BatchCommitWriteStreamsRequest(
+        )
+        batch_commit_write_streams_request.parent = parent
+        batch_commit_write_streams_request.write_streams = [stream_name]
+        bq_storage_client.batch_commit_write_streams(
+            batch_commit_write_streams_request)
 
         return response_future_1
 
-
     def batch_load_from_gcs(self, gcs_uri, table_destination, file_format):
         '''
             Batch loads a file from gcs into big query
@@ -99,8 +101,8 @@ class Wrapper:
             write_disposition=bigquery.WriteDisposition.WRITE_TRUNCATE,
             source_format=self.file_format_map[file_format])
         load_job = self.__google_big_query_client.load_table_from_uri(
-            gcs_uri, table_destination, job_config=job_config
-        )  # Make an API request.
+            gcs_uri, table_destination,
+            job_config=job_config)  # Make an API request.
         try:
             load_job.result()
             return True
@@ -108,8 +110,6 @@ class Wrapper:
             print_error(str(e))
             return False
 
-    
-
     def create_dataset_if_not_exist(self, dataset_id, location):
         '''
             Creates the client's Dataset if it does not already exist
@@ -119,15 +119,16 @@ class Wrapper:
             Returns:
                 boolean: True if the dataset already exists or was created, False if otherwise
         '''
-        dataset             = self.get_dataset(dataset_id)
+        dataset = self.get_dataset(dataset_id)
 
         if dataset is None:
             return False
 
-        dataset.location    = location
+        dataset.location = location
         # Check if dataset exists
         if self.check_if_dataset_exists(dataset_id):
-            print("Dataset {} already exists, skipping this step".format(dataset_id))
+            print("Dataset {} already exists, skipping this step".format(
+                dataset_id))
             return True
 
         print("Creating dataset: " + dataset_id)
@@ -135,7 +136,6 @@ class Wrapper:
 
         return self.check_if_dataset_exists(dataset_id)
 
-
     def get_dataset(self, dataset_id):
         '''
             Gets the dataset in bigquery
@@ -147,11 +147,10 @@ class Wrapper:
         try:
             return bigquery.Dataset(dataset_id)
         except Exception as e:
-            Helpers.print_error('Could not retreive dataset ' + dataset_id + " " + str(e))
+            Helpers.print_error('Could not retreive dataset ' + dataset_id +
+                                " " + str(e))
             return None
 
-        
-
     def create_table_if_not_exist(self, dataset_id, table_name, schema):
         '''
             Creates the client's PATIENT table if it does not already exist
@@ -162,19 +161,19 @@ class Wrapper:
                 boolean: True if the table was created or already existed, false
                     if table creation failed
         '''
-        # create table object  
-        table_id    = dataset_id + "." + table_name
-        table       = bigquery.Table(table_id, schema=schema)
+        # create table object
+        table_id = dataset_id + "." + table_name
+        table = bigquery.Table(table_id, schema=schema)
 
         if self.check_if_table_exists(table_id):
-            print("Table {} already exists, skipping this step".format(table_id))
+            print(
+                "Table {} already exists, skipping this step".format(table_id))
             return True
-                    
+
         print("Creating table " + table_id)
         table = self.create_table(table)
-            
+
         return self.check_if_table_exists(table_id)
-        
 
     def create_table(self, table):
         '''
@@ -190,7 +189,6 @@ class Wrapper:
             Helpers.print_error("Could not connect to GCS client " + str(e))
             sys.exit(1)
 
-
     def create_dataset(self, dataset):
         '''
             Creates Big Query Dataset
@@ -205,7 +203,6 @@ class Wrapper:
             Helpers.print_error("Could not connect to GCS client " + str(e))
             sys.exit(1)
 
-
     def check_if_table_exists(self, table_id):
         '''
             Checks if the table Id passed exists on GCP
@@ -215,7 +212,8 @@ class Wrapper:
                 boolean: True if the table exists, false if other wise
         '''
         try:
-            self.__google_big_query_client.get_table(table_id)  # Make an API request.
+            self.__google_big_query_client.get_table(
+                table_id)  # Make an API request.
             return True
         except NotFound:
             return False
@@ -223,7 +221,6 @@ class Wrapper:
             print(str(e))
             return False
 
-
     def check_if_dataset_exists(self, dataset_id):
         '''
             Checks if the dataset ID passed exists on GCP
@@ -233,7 +230,8 @@ class Wrapper:
                 boolean: True if the datset exists, false if other wise
         '''
         try:
-            self.__google_big_query_client.get_dataset(dataset_id)  # Make an API request.
+            self.__google_big_query_client.get_dataset(
+                dataset_id)  # Make an API request.
             return True
         except NotFound:
             return False
@@ -241,7 +239,6 @@ class Wrapper:
             print(str(e))
             return False
 
-
     def delete_table(self, table_id):
         '''
             Deletes a table
@@ -257,7 +254,6 @@ class Wrapper:
             print_error('Failed to Delete table: ' + table_id + " " + str(e))
             return False
 
-
     def perform_query(self, query):
         '''
             Performs a big query query
@@ -267,14 +263,13 @@ class Wrapper:
                 query_job: The job of the query 
         '''
         try:
-            query_job   = self.__google_big_query_client.query(query)
-            rows        = query_job.result()
+            query_job = self.__google_big_query_client.query(query)
+            rows = query_job.result()
             return rows
         except Exception as e:
             Helpers.print_error('Could not connect to GCS Big Query ' + str(e))
             return None
 
-
     def set_permissions_on_dataset(self, dataset_id, role, account):
         '''
             Function that sets the permissions of a dataset
@@ -285,30 +280,27 @@ class Wrapper:
             Returns:
                 boolean: True if the permissions were set, False if otherwise
         '''
-        dataset     = self.get_dataset(dataset_id)
+        dataset = self.get_dataset(dataset_id)
         entity_type = EntityTypes.USER_BY_EMAIL
-        entries     = list(dataset.access_entries)
+        entries = list(dataset.access_entries)
         # need to add an owner role to the dataset to set the SA permissions
         entries.append(
             bigquery.AccessEntry(
                 role='roles/bigquery.dataOwner',
                 entity_type=entity_type,
                 entity_id=DATASET_OWNER,
-            )
-        )
+            ))
         entries.append(
             bigquery.AccessEntry(
                 role=role,
                 entity_type=entity_type,
                 entity_id=account,
-            )
-        )
-        
+            ))
+
         dataset.access_entries = entries
 
         return self.update_dataset(dataset, ["access_entries"])
 
-
     def update_dataset(self, dataset, fields):
         '''
             Updates a dataset with the fields passed
@@ -324,4 +316,3 @@ class Wrapper:
         except Exception as e:
             print_error(e)
             return False
-
