@@ -6,6 +6,8 @@
 import datetime
 import uuid
 from indxdatalaketools import Helpers
+from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
+
 
 class Wrapper:
     '''
@@ -13,8 +15,9 @@ class Wrapper:
     '''
     __google_cloud_storage_client = None
 
-    def __init__(self, google_clients):
-        self.__google_cloud_storage_client = google_clients.cloud_storage_client
+    def __init__(self):
+        self.__google_cloud_storage_client = GcpClients.instance(
+        ).get_storage_client()
 
     def find_blobs_with_metadata(self, bucket, key, value, path_prefix=''):
         '''
@@ -28,8 +31,10 @@ class Wrapper:
                 list: list containing all blobs with mathcing metadata
         '''
         blobs = []
-        for blob in self.__google_cloud_storage_client.list_blobs(bucket, prefix=path_prefix):
-            if blob.metadata is not None and key in blob.metadata and blob.metadata[key] == value:
+        for blob in self.__google_cloud_storage_client.list_blobs(
+                bucket, prefix=path_prefix):
+            if blob.metadata is not None and key in blob.metadata and blob.metadata[
+                    key] == value:
                 blobs.append(blob.name)
 
         return blobs
@@ -60,24 +65,30 @@ class Wrapper:
                 upload_result: boolean - true if file upload successful, false if failure encountered
         '''
         if 'gs://' in file_path:
-            bucket_name         = file_path.replace("gs://", '').split('/')[0]
-            gcs_file_path       = file_path.replace("gs://"+bucket_name+"/",'')
-            blob_name           = prefix + "/" + mrn + "_" + str(uuid.uuid4()) + "_" + file_path.split('/')[-1]
-            source_bucket       = self.__google_cloud_storage_client.bucket(bucket_name)
-            destination_bucket  = self.__google_cloud_storage_client.bucket(client_uuid)
-            blob                = source_bucket.blob(gcs_file_path)
-            blob_copy           = source_bucket.copy_blob(blob, destination_bucket, new_name = blob_name)
-            
+            bucket_name = file_path.replace("gs://", '').split('/')[0]
+            gcs_file_path = file_path.replace("gs://" + bucket_name + "/", '')
+            blob_name = prefix + "/" + mrn + "_" + str(
+                uuid.uuid4()) + "_" + file_path.split('/')[-1]
+            source_bucket = self.__google_cloud_storage_client.bucket(
+                bucket_name)
+            destination_bucket = self.__google_cloud_storage_client.bucket(
+                client_uuid)
+            blob = source_bucket.blob(gcs_file_path)
+            blob_copy = source_bucket.copy_blob(blob,
+                                                destination_bucket,
+                                                new_name=blob_name)
+
             if blob_copy.exists():
                 return blob_copy
             return False
         else:
-            file_path           = file_path.replace("\\", "/")
-            file_name           = file_path.split("/")[-1]
-            blob_name           = prefix + "/" + mrn + "_" + str(uuid.uuid4()) + "_" + file_name
-            bucket              = self.__google_cloud_storage_client.bucket(client_uuid)
-            blob                = bucket.blob(blob_name)
-            upload_result       = self.__upload_blob_from_local(blob, file_path)
+            file_path = file_path.replace("\\", "/")
+            file_name = file_path.split("/")[-1]
+            blob_name = prefix + "/" + mrn + "_" + str(
+                uuid.uuid4()) + "_" + file_name
+            bucket = self.__google_cloud_storage_client.bucket(client_uuid)
+            blob = bucket.blob(blob_name)
+            upload_result = self.__upload_blob_from_local(blob, file_path)
 
             if not upload_result:
                 return upload_result
@@ -98,4 +109,3 @@ class Wrapper:
         except Exception as e:
             Helpers.print_error("Could not connect to GCS client " + str(e))
             return False
-
