@@ -3,6 +3,7 @@
 #   Created on 6/14/2022
 #
 
+from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
 from indxdatalaketools.Helpers import print_error
 
 
@@ -12,8 +13,8 @@ class Wrapper:
     '''
     __google_cloud_tasks_client = None
 
-    def __init__(self, google_clients):
-        self.__google_cloud_tasks_client = google_clients.cloud_tasks_client
+    def __init__(self):
+        self.__google_cloud_tasks_client = GcpClients.instance().get_tasks_v2_client()
 
     def create_http_task(self, parent, task):
         '''
