@@ -5,6 +5,7 @@
 #   Helper functions used in the datalake tools
 
 import ast
+import csv
 import hashlib
 import sys
 import os
@@ -12,10 +13,24 @@ import os
 import requests
 
 
+def read_batch_file(file_name: str) -> list:
+    ''' Reads the contents of the batch file and returns a list of lists
+
+        Args:
+            file_name (str): The path of the file we are reading
+        
+        Returns:
+            list: A list of list containing all of the information in the header
+        '''
+    batch_list = []
+    with open(file_name) as csvfile:
+        spamreader = csv.reader(csvfile, delimiter=',', quotechar='|')
+        for row in spamreader:
+            batch_list.append(row)
+
+    return batch_list
+
 
-#
-#   REVIEWERS: Is there a better way to handle these cases? (missing underscore)
-#
 def convert_keys_in_dictionary(patient_data):
     '''
         This function converts the keys in the patient data dictionary
@@ -28,7 +43,7 @@ def convert_keys_in_dictionary(patient_data):
     converted_patient_data = {}
 
     for key, value in patient_data.items():
-        new_key = key.lower().replace("_","-")
+        new_key = key.lower().replace("_", "-")
         if "name" in new_key:
             new_key = new_key.replace("name", "-name")
         if value is None:
@@ -115,7 +130,6 @@ def print_error(*args, **kwargs):
     print(*args, file=sys.stderr, **kwargs)
 
 
-
 def create_service_account_name(client_uuid):
     '''
         Function that creates an md5 hash of the client uuid then removes the last 8 letters of it
@@ -125,14 +139,14 @@ def create_service_account_name(client_uuid):
         Returns:
             string: the service account name
     '''
-    md5_hash                = hashlib.md5()
-    encoded                 = client_uuid.encode()
+    md5_hash = hashlib.md5()
+    encoded = client_uuid.encode()
     md5_hash.update(encoded)
-    md_5_clientuuid         = md5_hash.hexdigest()
-    service_account_name    = 'client' + str(md_5_clientuuid)[0:24]
+    md_5_clientuuid = md5_hash.hexdigest()
+    service_account_name = 'client' + str(md_5_clientuuid)[0:24]
 
     return service_account_name
-    
+
 
 def hash_contents_to_file_name(file_path, contents):
     """
@@ -173,12 +187,12 @@ def patient_hash(client_id, patient_mrn_list):
                 break
         if patient == 'UNKNOWN':
             patient_hash_list.append('UNKNOWN')
-        client_patient = client_id.strip()+patient.strip()
+        client_patient = client_id.strip() + patient.strip()
         encoded_patient = client_patient.encode()
         hash_patient = hashlib.sha1(encoded_patient)
         patient_id = hash_patient.hexdigest()
         patient_hash_list.append(patient_id)
-    
+
     return patient_hash_list
 
 
@@ -190,11 +204,16 @@ def determine_json_structure(json_data):
         Returns:
             dict: dictionary depiction of metadata
     """
+    # json data is None, or empty string
+    if json_data is None or (isinstance(json_data, str) and json_data == ""):
+        return {}
+
+    # is already json instance
     if isinstance(json_data, dict) or isinstance(json_data, list):
         return json_data
 
+    # json string
     if "{" in json_data or '[' in json_data:
-        # json string
         result = ast.literal_eval(json_data)
         return result
     else:
@@ -203,7 +222,7 @@ def determine_json_structure(json_data):
             data = file.read()
             result = ast.literal_eval(data)
         return result
-    
+
 
 def create_get_request(url, params={}, headers={}):
     """
@@ -220,7 +239,7 @@ def create_get_request(url, params={}, headers={}):
         r.raise_for_status()
         return r.json()
     except requests.exceptions.HTTPError as err:
-        print_error('get request to ' + url +' failed ' + str(err))
+        print_error('get request to ' + url + ' failed ' + str(err))
         return None
 
 
@@ -240,5 +259,5 @@ def create_post_request(url, body, params={}, headers={}):
         r.raise_for_status()
         return r.json()
     except requests.exceptions.HTTPError as err:
-        print_error('post request to ' + url +' failed ' + str(err))
+        print_error('post request to ' + url + ' failed ' + str(err))
         return None
\ No newline at end of file
